Module azure

Module azure 

Structs

AzureBuilder
Configure Azure authentication credentials.
AzureConfig
Configuration for Azure authentication

Enums

AzureConfigKey
Configuration keys for AzureBuilder
AzureCredential
An Azure storage credential.

Constants

DEFAULT_TTL_SECS
Default SAS TTL in seconds (1 hour).

Functions

fetch_client_secret_token
Fetch a short-lived Azure storage bearer token using an OAuth2 client-secret flow.
fetch_managed_identity_token
Fetch a short-lived Azure storage bearer token using IMDS managed identity.
fetch_workload_identity_token
Fetch a short-lived Azure storage bearer token using workload identity (federated token file).
generate_storage_key_sas
Generate a service SAS token scoped to an Azure Blob Storage container and optionally a directory prefix (ADLS Gen2 sdd= scoping) using a storage account key.
generate_user_delegation_sas
Generate a User Delegation SAS token scoped to an Azure Blob Storage container and optionally a directory prefix within it (ADLS Gen2 sdd= scoping).

Type Aliases

AzureCredentialProvider