#[non_exhaustive]pub enum ClientConfigKey {
Show 16 variants
AllowHttp,
AllowInvalidCertificates,
ConnectTimeout,
Http1Only,
Http2KeepAliveInterval,
Http2KeepAliveTimeout,
Http2KeepAliveWhileIdle,
Http2MaxFrameSize,
Http2Only,
PoolIdleTimeout,
PoolMaxIdlePerHost,
ProxyUrl,
ProxyCaCertificate,
ProxyExcludes,
Timeout,
UserAgent,
}Expand description
Configuration keys for ClientOptions
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AllowHttp
Allow non-TLS, i.e. non-HTTPS connections
AllowInvalidCertificates
Skip certificate validation on https connections.
Warning
You should think very carefully before using this method. If invalid certificates are trusted, any certificate for any site will be trusted for use. This includes expired certificates. This introduces significant vulnerabilities, and should only be used as a last resort or for testing
ConnectTimeout
Timeout for only the connect phase of a Client
Http1Only
Only use http1 connections
Http2KeepAliveInterval
Interval for HTTP2 Ping frames should be sent to keep a connection alive.
Http2KeepAliveTimeout
Timeout for receiving an acknowledgement of the keep-alive ping.
Http2KeepAliveWhileIdle
Enable HTTP2 keep alive pings for idle connections
Http2MaxFrameSize
Sets the maximum frame size to use for HTTP2.
Http2Only
Only use http2 connections
PoolIdleTimeout
The pool max idle timeout
This is the length of time an idle connection will be kept alive
PoolMaxIdlePerHost
maximum number of idle connections per host
ProxyUrl
HTTP proxy to use for requests
ProxyCaCertificate
PEM-formatted CA certificate for proxy connections
ProxyExcludes
List of hosts that bypass proxy
Timeout
Request timeout
The timeout is applied from when the request starts connecting until the response body has finished
UserAgent
User-Agent header to be used by this client