pub enum Error {
ReqwestError(Error),
Generic {
source: Box<dyn Error + Send + Sync + 'static>,
},
NotFound {
source: Box<dyn Error + Send + Sync + 'static>,
},
AlreadyExists {
source: Box<dyn Error + Send + Sync + 'static>,
},
Precondition {
source: Box<dyn Error + Send + Sync + 'static>,
},
NotModified {
source: Box<dyn Error + Send + Sync + 'static>,
},
PermissionDenied {
source: Box<dyn Error + Send + Sync + 'static>,
},
Unauthenticated {
source: Box<dyn Error + Send + Sync + 'static>,
},
UnknownConfigurationKey {
key: String,
},
InvalidHeader(InvalidHeaderValue),
RecordingIo(Error),
ClockError,
}Variants
ReqwestError(Error)
Generic
NotFound
Error when the object is not found at given location
AlreadyExists
Error when the object already exists
Precondition
Error when the required conditions failed for the operation
NotModified
Error when the object at the location isn’t modified
PermissionDenied
Error when the used credentials don’t have enough permission to perform the requested operation
Unauthenticated
Error when the used credentials lack valid authentication
UnknownConfigurationKey
Error when a configuration key is invalid for the store used
InvalidHeader(InvalidHeaderValue)
Error constructing an HTTP header value from a string
RecordingIo(Error)
Error when writing a recording to disk
ClockError
Error when the system clock is before the Unix epoch