Structs
- Azure
Builder - Configure Azure authentication credentials.
- Azure
Config - Configuration for Azure authentication
Enums
- Azure
Config Key - Configuration keys for
AzureBuilder - Azure
Credential - An Azure storage credential.
Constants
- DEFAULT_
TTL_ SECS - Default SAS TTL in seconds (1 hour).
Functions
- fetch_
client_ secret_ token - Fetch a short-lived Azure storage bearer token using an OAuth2 client-secret flow.
- fetch_
managed_ identity_ token - Fetch a short-lived Azure storage bearer token using IMDS managed identity.
- fetch_
workload_ identity_ token - Fetch a short-lived Azure storage bearer token using workload identity (federated token file).
- generate_
storage_ key_ sas - Generate a service SAS token scoped to an Azure Blob Storage container and
optionally a directory prefix (ADLS Gen2
sdd=scoping) using a storage account key. - generate_
user_ delegation_ sas - Generate a User Delegation SAS token scoped to an Azure Blob Storage container
and optionally a directory prefix within it (ADLS Gen2
sdd=scoping).